pub async fn estimate_deletion_cnt(
context: &Context,
from_server: bool,
seconds: i64,
) -> Result<usize>Expand description
Estimates the number of messages that will be deleted
by the set_config()-option delete_device_after.
This is typically used to show the estimated impact to the user before actually enabling deletion of old messages.
Messages in the “Saved Messages” chat are not counted as they will not be deleted automatically.
Parameters:
from_server: Deprecated, passfalsehereseconds: Count messages older than the given number of seconds.
Returns the number of messages that are older than the given number of seconds.